@@ -79,9 +79,26 @@ class AbstractOperator(ABC):
         output_fields: Optional[List[str]] = None,
         enable_postprocess: Optional[bool] = True,
     ):
+        if input_fields is not None:
+            assert isinstance(input_fields, list), "`input_fields` must be of type list"
+            for field_index, input_field in enumerate(input_fields):
+                assert isinstance(
+                    input_field, str
+                ), f"input_field at index {field_index} of `input_fields` is not of type string"
+
+        if output_fields is not None:
+            assert isinstance(
+                output_fields, list
+            ), "`output_fields`  must be of type list"
+            for field_index, output_field in enumerate(output_fields):
+                assert isinstance(
+                    output_field, str
+                ), f"output_field at index {field_index} of `output_fields` is not of type string"
+
         self._input_fields = input_fields
         self._output_fields = output_fields
         self._enable_postprocess = enable_postprocess
+        self._n_processed_pricing = None
 
     def toggle_postprocess(self):
         self._enable_postprocess ^= True
@@ -167,17 +184,15 @@ class AbstractOperator(ABC):
         pass
 
     @property
-    def n_processed_pricing(self):
-        if hasattr(self, "_n_processed_pricing"):
-            return self._n_processed_pricing
-        return 0
+    def is_operator_based_pricing(self):
+        return self._n_processed_pricing is not None and self._n_processed_pricing > 0
 
-    @n_processed_pricing.getter
+    @property
     def n_processed_pricing(self):
-        # default it to 0
-        if hasattr(self, "_n_processed_pricing"):
+        if self._n_processed_pricing is not None:
             return self._n_processed_pricing
-        return 0
+        else:
+            return 0
 
     @n_processed_pricing.setter
     def n_processed_pricing(self, value):
